@@ -2,27 +2,24 @@ import pandas as pd
 import numpy as np
 from copy import deepcopy
 
-def run_norm(net, df=None, norm_type='zscore', axis='row', keep_orig=False):
+def run_norm(net, df=None, norm_type='zscore', axis='row'):
   '''
-  A dataframe (more accurately a dictionary of dataframes, e.g. mat,
-  mat_up...) can be passed to run_norm and a normalization will be run (
+  A dataframe can be passed to run_norm and a normalization will be run (
   e.g. zscore) on either the rows or columns
   '''
 
-  # df here is actually a dictionary of several dataframes, 'mat', 'mat_orig',
-  # etc
   if df is None:
     df = net.dat_to_df()
 
   if norm_type == 'zscore':
-    df, ser_mean, ser_std = zscore_df(df, axis, keep_orig)
+    df, ser_mean, ser_std = zscore_df(df, axis)
 
     net.dat['pre_zscore'] = {}
     net.dat['pre_zscore']['mean'] = ser_mean.values.tolist()
     net.dat['pre_zscore']['std'] = ser_std.values.tolist()
 
   if norm_type == 'qn':
-    df = qn_df(df, axis, keep_orig)
+    df = qn_df(df, axis)
 
   net.df_to_dat(df)
 
@@ -31,45 +28,40 @@ def run_norm(net, df=None, norm_type='zscore', axis='row', keep_orig=False):
   #   net.dat['pre_zscore']['mean'] = ser_mean
   #   net.dat['pre_zscore']['std'] = ser_std
 
-def qn_df(df, axis='row', keep_orig=False):
+def qn_df(df, axis='row'):
   '''
   do quantile normalization of a dataframe dictionary, does not write to net
   '''
-  df_qn = {}
+  # using transpose to do row qn
+  if axis == 'row':
+    df = df.transpose()
 
-  for mat_type in df:
-    inst_df = df[mat_type]
+  missing_values = df.isnull().values.any()
 
-    # using transpose to do row qn
-    if axis == 'row':
-      inst_df = inst_df.transpose()
+  # make mask of missing values
+  if missing_values:
 
-    missing_values = inst_df.isnull().values.any()
+    # get nan mask
+    missing_mask = pd.isnull(df)
 
-    # make mask of missing values
-    if missing_values:
+    # tmp fill in na with zero, will not affect qn
+    df = df.fillna(value=0)
 
-      # get nan mask
-      missing_mask = pd.isnull(inst_df)
+  # calc common distribution
+  common_dist = calc_common_dist(df)
 
-      # tmp fill in na with zero, will not affect qn
-      inst_df = inst_df.fillna(value=0)
+  # swap in common distribution
+  df = swap_in_common_dist(df, common_dist)
 
-    # calc common distribution
-    common_dist = calc_common_dist(inst_df)
+  # swap back in missing values
+  if missing_values:
+    df = df.mask(missing_mask, other=np.nan)
 
-    # swap in common distribution
-    inst_df = swap_in_common_dist(inst_df, common_dist)
+  # using transpose to do row qn
+  if axis == 'row':
+    df = df.transpose()
 
-    # swap back in missing values
-    if missing_values:
-      inst_df = inst_df.mask(missing_mask, other=np.nan)
-
-    # using transpose to do row qn
-    if axis == 'row':
-      inst_df = inst_df.transpose()
-
-    df_qn[mat_type] = inst_df
+  df_qn = df
 
   return df_qn
 
@@ -133,31 +125,20 @@ def calc_common_dist(df):
 
   return common_dist
 
-def zscore_df(df, axis='row', keep_orig=False):
+def zscore_df(df, axis='row'):
   '''
   take the zscore of a dataframe dictionary, does not write to net (self)
   '''
-  df_z = {}
 
-  for mat_type in df:
+  if axis == 'row':
+    df = df.transpose()
 
-    if keep_orig and mat_type == 'mat':
-      mat_orig = deepcopy(df[mat_type])
+  ser_mean = df.mean()
+  ser_std = df.std()
 
-    inst_df = df[mat_type]
+  df_z = (df - ser_mean)/ser_std
 
-    if axis == 'row':
-      inst_df = inst_df.transpose()
-
-    ser_mean = inst_df.mean()
-    ser_std = inst_df.std()
-
-    df_z[mat_type] = (inst_df - ser_mean)/ser_std
-
-    if axis == 'row':
-      df_z[mat_type] = df_z[mat_type].transpose()
-
-  if keep_orig:
-    df_z['mat_orig'] = mat_orig
+  if axis == 'row':
+    df_z = df_z.transpose()
 
   return df_z, ser_mean, ser_std
